@@ -1,7 +1,7 @@
 #!/bin/sh
 
 packages="db-test-mysql-2.0 db-test-mysql-2.1 db-test-mysql-frontend-2.0 \
-          db-test-mysql-perl-2.0 db-test-pgsql-2.0 db-test-pgsql-2.1 \
+          db-test-mysql-perl-2.0 db-test-pgsql-2.0 db-test-pgsql-2.1 db-test-pgsql-2.2 \
           db-test-pgsql-migration-1.9 db-test-pgsql-migration-2.0 \
           db-test-multidbtype-2.0 db-test-sqlite-2.0
           db-test-sqlite3-2.0 "
